@@ -18,14 +18,13 @@ def extract(data: BinaryIO, source_dir: DirPath, output_dir: DirPath) -> None:
     output_dir = Path(output_dir)
     if not output_dir.is_dir():
         output_dir.mkdir()
-    extract_from_env(Environment(data), output_dir, Path(source_dir))
+    extract_from_env(Environment(data), Path(source_dir), output_dir)
 
 
 def extract_all(
     input_dir: DirPath,
     output_dir: DirPath,
     reset: bool = True,
-    clean_up: bool = False,
     portrait_dir: DirPath | None = None
 ) -> None:
     input_dir = Path(input_dir)
@@ -42,10 +41,8 @@ def extract_all(
 
     for path in input_dir.glob("**/*.ab"):
         if path.is_file():
-            env = Environment(path.as_posix())
-            extract_from_env(env, output_dir)
-            if clean_up:
-                path.unlink()
+            with open(path, "rb") as bundle:
+                extract_from_env(Environment(bundle), path.parent, output_dir)
 
     combine_textures(output_dir)
 
